@@ -14,8 +14,9 @@ from pymongo.common import validate_read_preference
 
 from mongoengine import signals
 from mongoengine.common import _import_class
+from mongoengine.base.common import get_document
 from mongoengine.errors import (OperationError, NotUniqueError,
-                                InvalidQueryError)
+                                InvalidQueryError, LookUpError)
 
 from mongoengine.queryset import transform
 from mongoengine.queryset.field_list import QueryFieldList
@@ -60,7 +61,6 @@ class BaseQuerySet(object):
         self._none = False
         self._as_pymongo = False
         self._as_pymongo_coerce = False
-        self._len = None
 
         # If inheritance is allowed, only return instances and instances of
         # subclasses of the class being used
@@ -331,14 +331,9 @@ class BaseQuerySet(object):
             :meth:`skip` that has been applied to this cursor into account when
             getting the count
         """
-        if self._limit == 0:
+        if self._limit == 0 and with_limit_and_skip:
             return 0
-        if with_limit_and_skip and self._len is not None:
-            return self._len
-        count = self._cursor.count(with_limit_and_skip=with_limit_and_skip)
-        if with_limit_and_skip:
-            self._len = count
-        return count
+        return self._cursor.count(with_limit_and_skip=with_limit_and_skip)
 
     def delete(self, write_concern=None, _from_doc_delete=False):
         """Delete the documents matched by the query.
@@ -827,9 +822,9 @@ class BaseQuerySet(object):
 
     # JSON Helpers
 
-    def to_json(self):
+    def to_json(self, *args, **kwargs):
         """Converts a queryset to JSON"""
-        return json_util.dumps(self.as_pymongo())
+        return json_util.dumps(self.as_pymongo(), *args, **kwargs)
 
     def from_json(self, json_data):
         """Converts json data to unsaved objects"""
@@ -1339,13 +1334,33 @@ class BaseQuerySet(object):
 
         return frequencies
 
-    def _fields_to_dbfields(self, fields):
+    def _fields_to_dbfields(self, fields, subdoc=False):
         """Translate fields paths to its db equivalents"""
         ret = []
+        subclasses = []
+        document = self._document
+        if document._meta['allow_inheritance']:
+            subclasses = [get_document(x)
+                          for x in document._subclasses][1:]
         for field in fields:
-            field = ".".join(f.db_field for f in
-                             self._document._lookup_field(field.split('.')))
-            ret.append(field)
+            try:
+                field = ".".join(f.db_field for f in
+                                 document._lookup_field(field.split('.')))
+                ret.append(field)
+            except LookUpError, err:
+                found = False
+                for subdoc in subclasses:
+                    try:
+                        subfield = ".".join(f.db_field for f in
+                                        subdoc._lookup_field(field.split('.')))
+                        ret.append(subfield)
+                        found = True
+                        break
+                    except LookUpError, e:
+                        pass
+
+                if not found:
+                    raise err
         return ret
 
     def _get_order_by(self, keys):
